@@ -2,9 +2,9 @@
 
 import warnings
 
-__version__ = "1.4.2"
+__version__ = "1.4.3"
 __author__ = "Sam Schott"
-__url__ = "https://github.com/SamSchott/maestral"
+__url__ = "https://samschott.github.io/maestral"
 
 
 # suppress Python 3.9 warning from rubicon-objc
