@@ -225,11 +225,7 @@ def convert_py_errors(func: Callable) -> Callable:
         try:
             return func(*args, **kwargs)
         except MaestralApiError as exc:
-            raise cli.RemoteApiError(exc.title, exc.message)
-        except ConnectionError:
-            raise cli.CliException("Could not connect to Dropbox")
-        except Exception as exc:
-            raise cli.CliException(f"{exc.__class__.__name__}: {exc.args[0]}")
+            raise cli.CliException(f"{exc.title}. {exc.message}")
 
     return wrapper
 
@@ -274,6 +270,21 @@ class DropboxPath(click.ParamType):
         self.file_okay = file_okay
         self.dir_okay = dir_okay
 
+    def convert(
+        self,
+        value: Optional[str],
+        param: Optional[click.Parameter],
+        ctx: Optional[click.Context],
+    ) -> Optional[str]:
+
+        if value is None:
+            return value
+
+        if not value.startswith("/"):
+            value = "/" + value
+
+        return value
+
     #
     # def shell_complete(
     #     self,
@@ -445,7 +456,7 @@ class OrderedGroup(click.Group):
             commands.append((name, cmd))
 
         # allow for 3 times the default spacing
-        if len(commands):
+        if len(commands) > 0:
             max_len = max(len(name) for name, cmd in commands)
             limit = formatter.width - 6 - max_len  # type: ignore
 
@@ -699,11 +710,11 @@ def auth():
 
 @auth.command(name="link", help="Link a new Dropbox account.")
 @click.option(
+    "--relink",
     "-r",
-    "relink",
     is_flag=True,
     default=False,
-    help="Relink to the current account. Keeps the sync state.",
+    help="Relink to the existing account. Keeps the sync state.",
 )
 @config_option
 @convert_py_errors
@@ -730,7 +741,9 @@ Unlink your Dropbox account.
 If Maestral is running, it will be stopped before unlinking.
 """,
 )
-@click.option("--yes", "-Y", is_flag=True, default=False)
+@click.option(
+    "--yes", "-Y", is_flag=True, default=False, help="Skip confirmation prompt."
+)
 @existing_config_option
 @convert_py_errors
 def auth_unlink(yes: bool, config_name: str) -> None:
@@ -798,9 +811,6 @@ def sharelink_create(
 
     from .daemon import MaestralProxy
 
-    if not dropbox_path.startswith("/"):
-        dropbox_path = "/" + dropbox_path
-
     expiry_dt: Optional[float]
 
     if expiry:
@@ -843,9 +853,6 @@ def sharelink_list(dropbox_path: Optional[str], config_name: str) -> None:
 
     from .daemon import MaestralProxy
 
-    if dropbox_path and not dropbox_path.startswith("/"):
-        dropbox_path = "/" + dropbox_path
-
     with MaestralProxy(config_name, fallback=True) as m:
         links = m.list_shared_links(dropbox_path)
 
@@ -1092,9 +1099,6 @@ def ls(long: bool, dropbox_path: str, include_deleted: bool, config_name: str) -
     from .utils import natural_size
     from .daemon import MaestralProxy
 
-    if not dropbox_path.startswith("/"):
-        dropbox_path = "/" + dropbox_path
-
     with MaestralProxy(config_name, fallback=True) as m:
 
         cli.echo("Loading...\r", nl=False)
@@ -1308,9 +1312,6 @@ def excluded_add(dropbox_path: str, config_name: str) -> None:
 
     from .daemon import MaestralProxy
 
-    if not dropbox_path.startswith("/"):
-        dropbox_path = "/" + dropbox_path
-
     if dropbox_path == "/":
         raise cli.CliException("Cannot exclude the root directory.")
 
@@ -1336,9 +1337,6 @@ def excluded_remove(dropbox_path: str, config_name: str) -> None:
 
     from .daemon import MaestralProxy, CommunicationError
 
-    if not dropbox_path.startswith("/"):
-        dropbox_path = "/" + dropbox_path
-
     if dropbox_path == "/":
         return cli.echo("The root directory is always included")
 
@@ -1432,9 +1430,12 @@ Rebuild the sync index.
 Rebuilding may take several minutes, depending on the size of your Dropbox.
 """,
 )
+@click.option(
+    "--yes", "-Y", is_flag=True, default=False, help="Skip confirmation prompt."
+)
 @existing_config_option
 @convert_py_errors
-def rebuild_index(config_name: str) -> None:
+def rebuild_index(yes: bool, config_name: str) -> None:
 
     import textwrap
     from .daemon import MaestralProxy
@@ -1448,13 +1449,13 @@ def rebuild_index(config_name: str) -> None:
             "your Dropbox. Any changes to local files will be synced once rebuilding "
             "has completed. If you stop the daemon during the process, rebuilding will "
             "start again on the next launch.\nIf the daemon is not currently running, "
-            "a rebuild will be schedules for the next startup.",
+            "a rebuild will be scheduled for the next startup.",
             width=width,
         )
 
         cli.echo(msg + "\n")
 
-        if cli.confirm("Do you want to continue?", default=False):
+        if yes or cli.confirm("Do you want to continue?", default=False):
 
             m.rebuild_index()
 
@@ -1542,10 +1543,6 @@ def diff(
 
     from .daemon import MaestralProxy
 
-    # Reason for rel_dbx_path: os.path.join does not like leading /
-    if not dropbox_path.startswith("/"):
-        dropbox_path = "/" + dropbox_path
-
     def download_and_compare(
         m: MaestralProxy, old_rev: str, new_rev: Optional[str] = None
     ) -> None:
@@ -1608,7 +1605,7 @@ def diff(
 
             index_base = cli.select(
                 message="New revision:",
-                options=list(e["desc"] for e in entries),
+                options=[e["desc"] for e in entries],
                 hint="(↓ to see more)" if len(entries) > 6 else "",
             )
 
@@ -1621,7 +1618,7 @@ def diff(
             comparable_versions = entries[index_base + 1 :]
             index_new = cli.select(
                 message="Old revision:",
-                options=list(e["desc"] for e in comparable_versions),
+                options=[e["desc"] for e in comparable_versions],
                 hint="(↓ to see more)" if len(comparable_versions) > 6 else "",
             )
 
@@ -1667,9 +1664,6 @@ def restore(dropbox_path: str, rev: str, limit: int, config_name: str) -> None:
 
     from .daemon import MaestralProxy
 
-    if not dropbox_path.startswith("/"):
-        dropbox_path = "/" + dropbox_path
-
     with MaestralProxy(config_name, fallback=True) as m:
 
         if not rev:
@@ -1817,8 +1811,9 @@ def config_get(key: str, config_name: str) -> None:
     from .config.main import DEFAULTS_CONFIG
     from .daemon import MaestralProxy, CommunicationError
 
+    # Check if the config key exists in any section.
     section = next(
-        iter(s for s, conf_dict in DEFAULTS_CONFIG if key in conf_dict), None
+        iter(sec for sec, secdict in DEFAULTS_CONFIG.items() if key in secdict), None
     )
 
     if not section:
@@ -1854,7 +1849,10 @@ def config_set(key: str, value: str, config_name: str) -> None:
     from .daemon import MaestralProxy, CommunicationError
 
     section, defaults = next(
-        iter((s, d) for s, d in DEFAULTS_CONFIG if key in d), (None, None)
+        iter(
+            (sec, secdict) for sec, secdict in DEFAULTS_CONFIG.items() if key in secdict
+        ),
+        (None, None),
     )
 
     if not section or not defaults:
