@@ -68,6 +68,7 @@ from .errors import (
     NotLinkedError,
     InvalidDbidError,
     SharedLinkError,
+    DropboxConnectionError,
 )
 from .config import MaestralState
 from .constants import DROPBOX_APP_KEY
@@ -123,7 +124,6 @@ PaginationResultType = Union[sharing.ListSharedLinksResult, files.ListFolderResu
 FT = TypeVar("FT", bound=Callable[..., Any])
 
 # create single requests session for all clients
-SESSION = create_session()
 _major_minor_version = ".".join(__version__.split(".")[:2])
 USER_AGENT = f"Maestral/v{_major_minor_version}"
 
@@ -137,35 +137,6 @@ CONNECTION_ERRORS = (
 )
 
 
-class SpaceUsage(users.SpaceUsage):
-    @property
-    def allocation_type(self) -> str:
-        if self.allocation.is_team():
-            return "team"
-        elif self.allocation.is_individual():
-            return "individual"
-        else:
-            return ""
-
-    def __str__(self) -> str:
-
-        if self.allocation.is_individual():
-            used = self.used
-            allocated = self.allocation.get_individual().allocated
-        elif self.allocation.is_team():
-            used = self.allocation.get_team().used
-            allocated = self.allocation.get_team().allocated
-        else:
-            return natural_size(self.used)
-
-        percent = used / allocated
-        return f"{percent:.1%} of {natural_size(allocated)} used"
-
-    @classmethod
-    def from_dbx_space_usage(cls, su: users.SpaceUsage) -> "SpaceUsage":
-        return cls(used=su.used, allocation=su.allocation)
-
-
 @contextlib.contextmanager
 def convert_api_errors(
     dbx_path: Optional[str] = None, local_path: Optional[str] = None
@@ -182,11 +153,17 @@ def convert_api_errors(
         raise dropbox_to_maestral_error(exc, dbx_path, local_path)
     # catch connection errors first, they may inherit from OSError
     except CONNECTION_ERRORS:
-        raise ConnectionError("Cannot connect to Dropbox")
+        raise DropboxConnectionError(
+            "Cannot connect to Dropbox",
+            "Please check you internet connection and try again later.",
+        )
     except OSError as exc:
         if exc.errno == errno.EPROTOTYPE:
             # Can occur on macOS, see https://bugs.python.org/issue33450
-            raise ConnectionError("Cannot connect to Dropbox")
+            raise DropboxConnectionError(
+                "Cannot connect to Dropbox",
+                "Please check you internet connection and try again later.",
+            )
         else:
             raise os_to_maestral_error(exc, dbx_path, local_path)
 
@@ -205,18 +182,26 @@ class DropboxClient:
 
     :param config_name: Name of config file and state file to use.
     :param timeout: Timeout for individual requests. Defaults to 100 sec if not given.
+    :param session: Optional requests session to use. If not given, a new session will
+        be created with :function:`dropbox.create_session`.
     """
 
     SDK_VERSION: str = "2.0"
 
     _dbx: Optional[Dropbox]
 
-    def __init__(self, config_name: str, timeout: float = 100) -> None:
+    def __init__(
+        self,
+        config_name: str,
+        timeout: float = 100,
+        session: Optional[requests.Session] = None,
+    ) -> None:
 
         self.config_name = config_name
         self.auth = OAuth2Session(config_name)
 
         self._timeout = timeout
+        self._session = session or create_session()
         self._backoff_until = 0
         self._dbx = None
         self._state = MaestralState(config_name)
@@ -329,7 +314,7 @@ class DropboxClient:
                 oauth2_access_token=access_token,
                 oauth2_access_token_expiration=access_token_expiration,
                 app_key=DROPBOX_APP_KEY,
-                session=SESSION,
+                session=self._session,
                 user_agent=USER_AGENT,
                 timeout=self._timeout,
             )
@@ -341,6 +326,57 @@ class DropboxClient:
         """The unique Dropbox ID of the linked account"""
         return self.auth.account_id
 
+    # ---- session management ----------------------------------------------------------
+
+    def close(self) -> None:
+        """Cleans up all resources like the request session/network connection."""
+        if self._dbx:
+            self._dbx.close()
+
+    def __enter__(self) -> "DropboxClient":
+        return self
+
+    def __exit__(self, *args) -> None:
+        self.close()
+
+    def clone(
+        self,
+        config_name: Optional[str] = None,
+        timeout: Optional[float] = None,
+        session: Optional[requests.Session] = None,
+    ) -> "DropboxClient":
+        """
+        Creates a new copy of the Dropbox client with the same defaults unless modified
+        by arguments to clone().
+
+        See constructor for original parameter descriptions.
+
+        :returns: A new instance of DropboxClient.
+        """
+
+        session = session or self._session
+
+        client = self.__class__(
+            config_name or self.config_name,
+            timeout or self._timeout,
+            session,
+        )
+
+        if self._dbx:
+            client._dbx = self._dbx.clone(session=session)
+
+        return client
+
+    def clone_with_new_session(self) -> "DropboxClient":
+        """
+        Creates a new copy of the Dropbox client with the same defaults but a new
+        requests session. Use :meth:`close()` to clean up any resources from the network
+        session when done using the copy.
+
+        :returns: A new instance of DropboxClient.
+        """
+        return self.clone(session=create_session())
+
     # ---- SDK wrappers ----------------------------------------------------------------
 
     def get_account_info(self, dbid: Optional[str] = None) -> users.FullAccount:
@@ -376,21 +412,37 @@ class DropboxClient:
 
         return res
 
-    def get_space_usage(self) -> SpaceUsage:
+    def get_space_usage(self) -> users.SpaceUsage:
         """
         :returns: The space usage of the currently linked account.
         """
         with convert_api_errors():
             res = self.dbx.users_get_space_usage()
 
-        # convert from users.SpaceUsage to SpaceUsage
-        space_usage = SpaceUsage.from_dbx_space_usage(res)
+        # query space usage type
+        if res.allocation.is_team():
+            usage_type = "team"
+        elif res.allocation.is_individual():
+            usage_type = "individual"
+        else:
+            usage_type = ""
+
+        # generate space usage string
+        if res.allocation.is_team():
+            used = res.allocation.get_team().used
+            allocated = res.allocation.get_team().allocated
+        else:
+            used = res.used
+            allocated = res.allocation.get_individual().allocated
+
+        percent = used / allocated
+        space_usage = f"{percent:.1%} of {natural_size(allocated)} used"
 
         # save results to config
-        self._state.set("account", "usage", str(space_usage))
-        self._state.set("account", "usage_type", space_usage.allocation_type)
+        self._state.set("account", "usage", space_usage)
+        self._state.set("account", "usage_type", usage_type)
 
-        return space_usage
+        return res
 
     def get_metadata(self, dbx_path: str, **kwargs) -> Optional[files.Metadata]:
         """
@@ -1230,18 +1282,12 @@ def dropbox_to_maestral_error(
                     "request. Please try to move fewer items at once."
                 )
                 err_cls = SyncError
-            else:
-                text = "Please check the logs or traceback for more information"
-                err_cls = SyncError
 
         elif isinstance(error, (files.CreateFolderError, files.CreateFolderEntryError)):
             title = "Could not create folder"
             if error.is_path():
                 write_error = error.get_path()
                 text, err_cls = _get_write_error_msg(write_error)
-            else:
-                text = "Please check the logs or traceback for more information"
-                err_cls = SyncError
 
         elif isinstance(error, files.DeleteError):
             title = "Could not delete item"
@@ -1263,9 +1309,6 @@ def dropbox_to_maestral_error(
                     "Dropbox. Please try again later."
                 )
                 err_cls = SyncError
-            else:
-                text = "Please check the logs or traceback for more information"
-                err_cls = SyncError
 
         elif isinstance(error, files.UploadError):
             title = "Could not upload file"
@@ -1275,9 +1318,6 @@ def dropbox_to_maestral_error(
             elif error.is_properties_error():
                 # this is a programming error in maestral
                 text = "Invalid property group provided."
-            else:
-                text = "Please check the logs or traceback for more information"
-                err_cls = SyncError
 
         elif isinstance(error, files.UploadSessionStartError):
             title = "Could not upload file"
@@ -1287,9 +1327,6 @@ def dropbox_to_maestral_error(
             elif error.is_concurrent_session_data_not_allowed():
                 # this is a programming error in maestral
                 text = "Uploading data not allowed when starting concurrent upload session."
-            else:
-                text = "Please check the logs or traceback for more information"
-                err_cls = SyncError
 
         elif isinstance(error, files.UploadSessionFinishError):
             title = "Could not upload file"
@@ -1308,9 +1345,6 @@ def dropbox_to_maestral_error(
                     "Dropbox. Please retry again later."
                 )
                 err_cls = SyncError
-            else:
-                text = "Please check the logs or traceback for more information"
-                err_cls = SyncError
 
         elif isinstance(error, files.UploadSessionLookupError):
             title = "Could not upload file"
@@ -1324,9 +1358,6 @@ def dropbox_to_maestral_error(
             elif error.is_unsupported_file():
                 text = "This file type cannot be downloaded but must be exported."
                 err_cls = UnsupportedFileError
-            else:
-                text = "Please check the logs or traceback for more information"
-                err_cls = SyncError
 
         elif isinstance(error, files.ListFolderError):
             title = "Could not list folder contents"
@@ -1392,6 +1423,10 @@ def dropbox_to_maestral_error(
             elif error.is_path_write():
                 write_error = error.get_path_write()
                 text, err_cls = _get_write_error_msg(write_error)
+            elif error.is_in_progress():
+                title = "Restore in progress"
+                text = "Please check again later if the restore completed"
+                err_cls = SyncError
 
         elif isinstance(error, files.GetMetadataError):
             title = "Could not get metadata"
@@ -1436,15 +1471,16 @@ def dropbox_to_maestral_error(
         elif isinstance(error, sharing.RevokeSharedLinkError):
             title = "Could not revoke shared link"
 
-            if error.is_shared_link_not_found():
+            if error.is_shared_link_malformed():
+                text = "The shared link is malformed."
+                err_cls = SharedLinkError
+
+            elif error.is_shared_link_not_found():
                 text = "The given link does not exist."
                 err_cls = NotFoundError
             elif error.is_shared_link_access_denied():
                 text = "You do not have access to revoke the shared link."
                 err_cls = InsufficientPermissionsError
-            elif error.is_shared_link_malformed():
-                text = "The shared link is malformed."
-                err_cls = SharedLinkError
             elif error.is_unsupported_link_type():
                 text = "The link type is not supported."
                 err_cls = SharedLinkError
