@@ -1,39 +1,23 @@
 # -*- coding: utf-8 -*-
 """
-This class provides constants used throughout the maestral, the GUI and CLI. It should
+This module provides constants used throughout the maestral, the GUI and CLI. It should
 be kept free of memory heavy imports.
 """
 
 # system imports
-import sys
-import os
 import platform
 from enum import Enum
 
-try:
-    from importlib.metadata import metadata, PackageNotFoundError  # type: ignore
-except ImportError:
-    # Backwards compatibility Python 3.7 and lower
-    from importlib_metadata import metadata, PackageNotFoundError  # type: ignore
 try:
     from importlib.resources import files  # type: ignore
 except ImportError:
     from importlib_resources import files  # type: ignore
 
 
-# get metadata of maestral-related packages
-_md_list = []
-
-for dist_name in ("maestral", "maestral-cocoa", "maestral-qt", "maestral-gui"):
-    try:
-        _md_list.append(metadata(dist_name))
-    except PackageNotFoundError:
-        pass
-
 # app
 APP_NAME = "Maestral"
 BUNDLE_ID = "com.samschott.maestral"
-APP_ICON_PATH = os.path.join(files("maestral"), "resources", "maestral.png")
+APP_ICON_PATH = files("maestral") / "resources" / "maestral.png"
 
 # sync
 OLD_REV_FILE = ".maestral"
@@ -83,10 +67,6 @@ class FileStatus(Enum):
 IS_MACOS = platform.system() == "Darwin"
 IS_LINUX = platform.system() == "Linux"
 
-# frozen app / bundle detection
-BRIEFCASE = any("Briefcase-Version" in md for md in _md_list)
-FROZEN = BRIEFCASE or getattr(sys, "frozen", False)
-
 # keys
 DROPBOX_APP_KEY = "2jmbq42w7vof78h"
 
