@@ -17,6 +17,9 @@ import struct
 import tempfile
 import logging
 import warnings
+import argparse
+import ast
+import re
 from shlex import quote
 from typing import Optional, Any, Union, Tuple, Dict, Iterable, Type, TYPE_CHECKING
 from types import TracebackType
@@ -30,7 +33,6 @@ from fasteners import InterProcessLock  # type: ignore
 
 # local imports
 from .errors import SYNC_ERRORS, GENERAL_ERRORS, MaestralApiError
-from .constants import IS_MACOS, FROZEN
 from .utils.appdirs import get_runtime_path
 
 
@@ -47,7 +49,7 @@ __all__ = [
     "sockpath_for_config",
     "lockpath_for_config",
     "is_running",
-    "set_executable",
+    "freeze_support",
     "start_maestral_daemon",
     "start_maestral_daemon_process",
     "stop_maestral_daemon_process",
@@ -72,23 +74,28 @@ IS_WATCHDOG = WATCHDOG_USEC and (
 URI = "PYRO:maestral.{0}@{1}"
 Pyro5.config.THREADPOOL_SIZE_MIN = 2
 
-if FROZEN and IS_MACOS:
-    EXECUTABLE = [sys.executable, "--run-python", "-OO"]
-else:
-    EXECUTABLE = [sys.executable, "-OO"]
 
-
-def set_executable(executable: str, *argv: str) -> None:
+def freeze_support() -> None:
     """
-    Sets the path of the Python executable to use when starting the daemon. By default
-    :obj:`sys.executable` is used. Can be used when embedding the daemon.
-
-    :param executable: Path to custom Python executable.
-    :param argv: Any command line arguments to be injected before the daemon startup
-        command. By default, "-OO" will be used.
+    Call this as early as possible in the main entry point of a frozen executable.
+    This call will start the sync daemon if a matching command line arguments are
+    detected and do nothing otherwise.
     """
-    global EXECUTABLE
-    EXECUTABLE = [executable, *argv]
+
+    parser = argparse.ArgumentParser()
+    parser.add_argument("-c")
+    parsed_args, _ = parser.parse_known_args()
+
+    if parsed_args.c:
+        template = r'.*start_maestral_daemon\("(?P<config_name>\S+)", start_sync=(?P<start_sync>\S+)\).*'
+        match = re.match(template, parsed_args.c)
+
+        if match:
+            config_name = match["config_name"]
+            start_sync = ast.literal_eval(match["start_sync"])
+
+            start_maestral_daemon(config_name, start_sync)
+            sys.exit()
 
 
 class Stop(enum.Enum):
@@ -119,8 +126,12 @@ def serpent_deserialize_api_error(class_name: str, d: dict) -> MaestralApiError:
     :param d: Dictionary of serialized class.
     :returns: Class instance.
     """
-    # import maestral errors for evaluation
-    # this import needs to be absolute to reconstruct the Exception class
+
+    # Import maestral.errors for evaluation.
+    # This import needs to be absolute to reconstruct the Exception class. Note that the
+    # eval is safe here because ``serpent_deserialize_api_error`` is only registered for
+    # strings that match an error class name.
+
     import maestral.errors  # noqa: F401
 
     cls = eval(class_name)
@@ -189,7 +200,7 @@ class Lock:
     method to create / retrieve a lock instance.
     """
 
-    _instances: Dict[str, "Lock"] = dict()
+    _instances: Dict[str, "Lock"] = {}
     _singleton_lock = threading.Lock()
 
     @classmethod
@@ -590,7 +601,7 @@ def start_maestral_daemon_process(
         f'maestral.daemon.start_maestral_daemon("{cc}", start_sync={start_sync})'
     )
 
-    cmd = [*EXECUTABLE, "-c", script]
+    cmd = [sys.executable, "-OO", "-c", script]
 
     process = subprocess.Popen(
         cmd,
@@ -762,7 +773,7 @@ class MaestralProxy:
 
     def __dir__(self) -> Iterable[str]:
         own_result = dir(self.__class__) + list(self.__dict__.keys())
-        proxy_result = list(k for k in self._m.__dir__() if not k.startswith("_"))
+        proxy_result = [k for k in self._m.__dir__() if not k.startswith("_")]
 
         return sorted(set(own_result) | set(proxy_result))
 
