@@ -62,7 +62,6 @@ class OAuth2Session:
         * MacOS Keychain
         * Any keyring implementing the SecretService Dbus specification
         * KWallet
-        * Gnome Keyring
         * Plain text storage
 
     When the auth flow is completed, a short-lived access token and a long-lived refresh
@@ -74,6 +73,10 @@ class OAuth2Session:
     tokens, the :attr:`token_access_type` will be 'legacy' and only a long-lived access
     token will be available.
 
+    .. note:: Once the token has been stored with a keyring backend, that backend will be
+        saved in the config file and remembered until the user unlinks the account. This
+        module will therefore never switch keyring backends while linked.
+
     .. warning:: Unlike MacOS Keychain, Gnome Keyring and KWallet do not support
         app-specific access to passwords. If the user unlocks those keyrings, we and any
         other application in the same user session get access to *all* saved passwords.
@@ -145,28 +148,29 @@ class OAuth2Session:
         keyring_class: str = self._conf.get("app", "keyring").strip()
 
         if self._account_id and keyring_class != "automatic":
-            # we are already linked and have a keyring set
+            # We are already linked and have a keyring set. Insist on using
+            # the recorded backend.
 
             try:
                 ring = load_keyring(keyring_class)
             except Exception as exc:
-                # reset the keyring and prompt to relink
-                # them bomb out with an exception
-
-                self._conf.set("app", "keyring", "automatic")
+                # Bomb out with an exception.
 
                 title = f"Cannot load keyring {keyring_class}"
-                message = "Please relink Maestral to get a new access token"
+                message = "Please relink Maestral to get a new access token."
                 new_exc = KeyringAccessError(title, message).with_traceback(
                     exc.__traceback__
                 )
                 logger.error(title, exc_info=_exc_info(new_exc))
                 raise new_exc
-            else:
-                return ring
+
+            return ring
 
         else:
 
+            # We are not yet linked. Try loading the preset or the preferred keyring
+            # backend for the platform.
+
             try:
                 ring = load_keyring(keyring_class)
             except Exception:
@@ -192,11 +196,11 @@ class OAuth2Session:
     def _get_accessor(self) -> str:
         return f"config:{self._config_name}:{self._account_id}"
 
-    def _migrate_keyring(self) -> None:
-        token = self.keyring.get_password("Maestral", self._account_id)
+    def _migrate_keyring(self, account_id: str) -> None:
+        token = self.keyring.get_password("Maestral", account_id)
         if token:
             self.keyring.set_password("Maestral", self._get_accessor(), token)
-            self.keyring.delete_password("Maestral", self._account_id)
+            self.keyring.delete_password("Maestral", account_id)
 
     @property
     def linked(self) -> bool:
@@ -282,7 +286,7 @@ class OAuth2Session:
 
         try:
 
-            self._migrate_keyring()
+            self._migrate_keyring(self._account_id)
 
             token = self.keyring.get_password("Maestral", self._get_accessor())
             access_type = self._state.get("account", "token_access_type")
@@ -310,11 +314,11 @@ class OAuth2Session:
                 self._token_access_type = access_type
 
         except (KeyringLocked, InitError):
-            title = f"Could not load auth token, {self.keyring.name} is locked"
-            msg = "Please unlock the keyring and try again."
-            exc = KeyringAccessError(title, msg)
-            logger.error(title, exc_info=_exc_info(exc))
-            raise exc
+            title = "Could not load auth token"
+            msg = f"{self.keyring.name} is locked. Please unlock the keyring and try again."
+            new_exc = KeyringAccessError(title, msg)
+            logger.error(title, exc_info=_exc_info(new_exc))
+            raise new_exc
 
     def get_auth_url(self) -> str:
         """
@@ -367,6 +371,9 @@ class OAuth2Session:
             else:
                 token = self.access_token
 
+            if not token:
+                raise RuntimeError("No credentials set")
+
             try:
                 self.keyring.set_password("Maestral", self._get_accessor(), token)
                 cli.ok("Credentials written")
@@ -394,8 +401,8 @@ class OAuth2Session:
                 self.keyring.delete_password("Maestral", self._get_accessor())
                 cli.ok("Credentials removed")
             except (KeyringLocked, InitError):
-                title = f"Could not delete auth token, {self.keyring.name} is locked"
-                msg = "Please unlock the keyring and try again."
+                title = "Could not delete auth token"
+                msg = f"{self.keyring.name} is locked. Please unlock the keyring and try again."
                 exc = KeyringAccessError(title, msg)
                 logger.error(title, exc_info=_exc_info(exc))
                 raise exc
